@@ -9,6 +9,8 @@ LOG_LEVELS = {
 
 
 def pytest_configure(config):
+    # Note: enable DEBUG logging to debug the parsing. But this becomes very
+    # verbose very quickly
     logging.basicConfig(
-        level=LOG_LEVELS.get(config.option.verbose, logging.DEBUG))
+        level=LOG_LEVELS.get(config.option.verbose, logging.INFO))
 
